function s = chirp(t, t_0, f_0, T, beta)
% chirp generates a Gaussian chirp signal 
%    a special case is a Gabor function
%
% file:      	chirp.m, (c) Matthew Roughan, Thu Aug 12 2004
% author:  	Matthew Roughan 
% email:   	matthew.roughan@adelaide.edu.au
% 
% see Bracewell, p. 135, 502
% and Mallat, p. 71, and 100
%
%    inputs:
%        t:      time points for chirp samples
%        t_0:    mid-pulse time        (t_0=u for a Gabor function)
%        f_0:    mid-pulse frequency   (f_0=xi for a Gabor function)
%        T:      Gaussian window width (T=1/b for a Gabor function)
%        2*beta: chirp sweep rate      (beta = 0 for a Gabor function)
%

s = exp(-pi*(t-t_0).^2/T) .* exp(i*2*pi*(f_0 * (t-t_0) + beta*(t-t_0).^2));

